/*  ========================================================================
    This file is part of TS UniDC Firmware.
    ------------------------------------------------------------------------
    $Id: $
    $Version: $
    $Copyright:  2008  Hochschule Landshut $
    $Author: Anton Hadinger <Anton.Hadinger@fh-landshut.de> $
    ------------------------------------------------------------------------
    TS UniDC Firmware is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    TS UniDC Firmware is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with TS UniDC Firmware; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
    ========================================================================*/

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
#include "firmware.h"
#include "smbus0.h"

#include <string.h>


volatile __bit smbus0_mutex;
volatile unsigned char smbus0_cnt;
volatile unsigned char __xdata* smbus0_ptr;
static unsigned char __xdata smbus0_raw[16];

static const unsigned char code lcd_init [] =
{
	0x00,			// CTRL: Co=0; RS=0; R/W=0
	0x3E,			// IR: Funktion set; DL=1; N=1; M=1; G=1
	0x0E,			// IR: Display control; D=1; C=1; B=0
	0x06,			// IR: Entry mode set; I/O=1; S=0
};


void
smbus0_isr (void)
interrupt 7 using 2
{
	switch (SMB0STA)
	{
		case SMB_START:			// 0x08
			SMB0DAT = LCD_I2C_ID | SMB_WRITE;
			STA = 0;
			break;

		case SMB_MTADDACK:		// 0x18
			SMB0DAT = *smbus0_ptr++;
			smbus0_cnt--;
			break;

		case SMB_MTDBACK:		// 0x28
			if (smbus0_cnt)
			{
				SMB0DAT = *smbus0_ptr++;
				smbus0_cnt--;
			}
			else
			{
				STO = 1;
				smbus0_mutex = 0;
			}
			break;

		default:
			smbus0_mutex = 0;
			break;
	}

	SI = 0;
}

static void
smbus0_xmit (void)
{
	while (smbus0_mutex);

	smbus0_mutex = 1;
	EIE1 |= ESMB0;

	STO = 0;
	STA = 1;

	while (smbus0_mutex);

	EIE1 &= ~ESMB0;
}

void
lcd_reset (void)
{
	unsigned char n,x;

	smbus0_mutex = 0;

	memcpy (smbus0_raw, lcd_init, sizeof (lcd_init));
	smbus0_ptr = smbus0_raw;
	smbus0_cnt = sizeof (lcd_init);
	smbus0_xmit ();

	n = 4;
	while (n--)
	{
		x = 0x10;
		while (x)
		{
			P5 = x | 0x0F;
			x *= 2;
			wait_1ms (20);
		}
	}
}

void
lcd_putch (unsigned char offs, char ch)
{
	smbus0_raw[0] = 0x80;					// CTRL: Co=1; RS=0; R/W=0
	smbus0_raw[1] = 0x80 + offs;			// IR: Set DDRAM address
	smbus0_raw[2] = 0x40;					// CTRL: Co=0; RS=1; R/W=0
	smbus0_raw[3] = ch | 0x80;

	smbus0_cnt = 4;
	smbus0_ptr = smbus0_raw;
	smbus0_xmit ();
}

void
lcd_text (unsigned char offs, const char *txt)
{
	unsigned char n = LcdColumns;

	smbus0_raw[0] = 0x80;					// CTRL: Co=1; RS=0; R/W=0
	smbus0_raw[1] = 0x80 + offs;			// IR: Set DDRAM address
	smbus0_raw[2] = 0x40;					// CTRL: Co=0; RS=1; R/W=0

	smbus0_cnt = 3;
	smbus0_ptr = smbus0_raw+3;
	while (*txt != '\0')
	{
		*smbus0_ptr++ = *txt++ | 0x80;
		smbus0_cnt++;
		if (--n==0){ break; }
	}

	smbus0_ptr = smbus0_raw;
	smbus0_xmit ();
}
